Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(169)

Unified Diff: device/usb/usb_device.h

Issue 562763002: Convert device::UsbConfigDescriptor and friends to structs. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Add interface and endpoint descriptor iterator typedefs. Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « device/usb/usb_descriptors.cc ('k') | device/usb/usb_device_filter.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: device/usb/usb_device.h
diff --git a/device/usb/usb_device.h b/device/usb/usb_device.h
index 586fd19cdce706c59b50c48b3ed621b95e22ea3f..a012025b35784be2a1e1f90f467e80c9d1938973 100644
--- a/device/usb/usb_device.h
+++ b/device/usb/usb_device.h
@@ -12,7 +12,7 @@
namespace device {
class UsbDeviceHandle;
-class UsbConfigDescriptor;
+struct UsbConfigDescriptor;
// A UsbDevice object represents a detected USB device, providing basic
// information about it. For further manipulation of the device, a
@@ -44,10 +44,9 @@ class UsbDevice : public base::RefCountedThreadSafe<UsbDevice> {
// Blocking method. Must be called on FILE thread.
virtual bool Close(scoped_refptr<UsbDeviceHandle> handle) = 0;
// Lists the interfaces provided by the device and fills the given
// UsbConfigDescriptor.
// Blocking method. Must be called on FILE thread.
- virtual scoped_refptr<UsbConfigDescriptor> ListInterfaces() = 0;
+ virtual const UsbConfigDescriptor& GetConfiguration() = 0;
protected:
UsbDevice(uint16 vendor_id, uint16 product_id, uint32 unique_id)
« no previous file with comments | « device/usb/usb_descriptors.cc ('k') | device/usb/usb_device_filter.cc » ('j') | no next file with comments »
@@ -44,10 +44,9 @@ class UsbDevice : public base::RefCountedThreadSafe<UsbDevice> {
// Blocking method. Must be called on FILE thread.
virtual bool Close(scoped_refptr<UsbDeviceHandle> handle) = 0;
- // Lists the interfaces provided by the device and fills the given
- // UsbConfigDescriptor.
+ // Gets the UsbConfigDescriptor for the active device configuration.
// Blocking method. Must be called on FILE thread.

Powered by Google App Engine
This is Rietveld 408576698